==> zio-aws-appsync_3-5.17.115.1-sources.jar: zio/aws/appsync/model/CreateTypeResponse.scala <==
package zio.aws.appsync.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateTypeResponse(
    `type`: Option[zio.aws.appsync.model.Type] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.CreateTypeResponse = {
    import CreateTypeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.CreateTypeResponse
      .builder()
      .optionallyWith(`type`.map(value => value.buildAwsValue()))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.appsync.model.CreateTypeResponse.ReadOnly =
    zio.aws.appsync.model.CreateTypeResponse.wrap(buildAwsValue())
}
object CreateTypeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.CreateTypeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.CreateTypeResponse =
      zio.aws.appsync.model
        .CreateTypeResponse(`type`.map(value => value.asEditable))
    def `type`: Option[zio.aws.appsync.model.Type.ReadOnly]
    def getType: ZIO[Any, AwsError, zio.aws.appsync.model.Type.ReadOnly] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.CreateTypeResponse
  ) extends zio.aws.appsync.model.CreateTypeResponse.ReadOnly {
    override val `type`: Option[zio.aws.appsync.model.Type.ReadOnly] = scala
      .Option(impl.`type`())
      .map(value => zio.aws.appsync.model.Type.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.CreateTypeResponse
  ): zio.aws.appsync.model.CreateTypeResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appsync_3-6.20.83.1-sources.jar: zio/aws/appsync/model/CreateTypeResponse.scala <==
package zio.aws.appsync.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateTypeResponse(
    `type`: Optional[zio.aws.appsync.model.Type] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.CreateTypeResponse = {
    import CreateTypeResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.CreateTypeResponse
      .builder()
      .optionallyWith(`type`.map(value => value.buildAwsValue()))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.appsync.model.CreateTypeResponse.ReadOnly =
    zio.aws.appsync.model.CreateTypeResponse.wrap(buildAwsValue())
}
object CreateTypeResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.CreateTypeResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.CreateTypeResponse =
      zio.aws.appsync.model
        .CreateTypeResponse(`type`.map(value => value.asEditable))
    def `type`: Optional[zio.aws.appsync.model.Type.ReadOnly]
    def getType: ZIO[Any, AwsError, zio.aws.appsync.model.Type.ReadOnly] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.CreateTypeResponse
  ) extends zio.aws.appsync.model.CreateTypeResponse.ReadOnly {
    override val `type`: Optional[zio.aws.appsync.model.Type.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.appsync.model.Type.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.CreateTypeResponse
  ): zio.aws.appsync.model.CreateTypeResponse.ReadOnly = new Wrapper(impl)
}
